@@ -16,7 +16,11 @@
 // with Gnome Weather; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+const Gtk = imports.gi.Gtk;
+const Lang = imports.lang;
+
 const Forecast = imports.forecast;
+const Params = imports.params;
 const Util = imports.util;
 
 const SPINNER_SIZE = 128;
@@ -35,6 +39,8 @@ const WeatherWidget = new Lang.Class({
         let builder = new Gtk.Builder();
         builder.add_from_resource('/org/gnome/weather/city.ui');
 
+        let rtl = this.get_direction() == Gtk.TextDirection.RTL;
+
         let outerBox = builder.get_object('outer-box');
         this._contentFrame = builder.get_object('content-frame');
         let outerGrid = builder.get_object('outer-grid');
@@ -44,6 +50,8 @@ const WeatherWidget = new Lang.Class({
         this._revealButton = builder.get_object('reveal-button');
         this._revealer = builder.get_object('revealer');
 
+        this._revealButton.get_child().icon_name = rtl ? 'go-previous-rtl-symbolic' : 'go-previous-symbolic';
+
         this._forecasts = new Forecast.ForecastBox({ hexpand: true });
         outerGrid.attach(this._forecasts, 0, 1, 1, 1);
 
@@ -54,10 +62,10 @@ const WeatherWidget = new Lang.Class({
         this._revealButton.connect('clicked', Lang.bind(this, function() {
             if (this._revealer.reveal_child) {
                 this._revealer.reveal_child = false;
-                this._revealButton.get_child().icon_name = 'go-previous-symbolic';
+                this._revealButton.get_child().icon_name = rtl ? 'go-previous-rtl-symbolic' : 'go-previous-symbolic';
             } else {
                 this._revealer.reveal_child = true;
-                this._revealButton.get_child().icon_name = 'go-next-symbolic';
+                this._revealButton.get_child().icon_name = rtl ? 'go-next-rtl-symbolic' : 'go-next-symbolic';
             }
         }));
 
