@@ -16,7 +16,14 @@
 // with Gnome Weather; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
+const Gtk = imports.gi.Gtk;
+const GWeather = imports.gi.GWeather;
+const Lang = imports.lang;
+
 const City = imports.city;
+const Params = imports.params;
 const World = imports.world;
 const Util = imports.util;
 
@@ -120,6 +127,10 @@ const MainWindow = new Lang.Class({
         let goWorldButton = builder.get_object('world-button');
         this._pageWidgets[Page.CITY].push(goWorldButton);
 
+        let goWorldButtonImage = builder.get_object('world-button-image');
+        goWorldButtonImage.icon_name = (goWorldButton.get_direction() == Gtk.TextDirection.RTL ?
+                                        'go-previous-rtl-symbolic' : 'go-previous-symbolic');
+
         let select = builder.get_object('select-button');
         this._pageWidgets[Page.WORLD].push(select);
 
